from setuptools import setup, find_packages

setup(
    name="rasmas",  # Package name (must be unique on PyPI)
    version="0.1.1",  # Package version
    packages=find_packages(),  # Automatically finds `rasmas` package
    install_requires=[
        "tqdm",
    ],  # Dependencies
    author="Mustafizur Rahaman",
    author_email="mustafiz0905@gmail.com",
    description="A Python package for raster clipping, conversion, masking and beyond",
    # long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/MustfizurRahaman/raster_master",
    classifiers=[
        "Programming Language :: Python :: 3",
	"Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
